contexttools.get_instrument_mark_attached_to_component
======================================================

.. autofunction:: abjad.tools.contexttools.get_instrument_mark_attached_to_component.get_instrument_mark_attached_to_component
